(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     30629,        855]*)
(*NotebookOutlinePosition[     31505,        888]*)
(*  CellTagsIndexPosition[     31406,        881]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Statistical behaviour of trace derivatives", "Title"],

Cell[CellGroupData[{

Cell["Data Loading", "Section"],

Cell["\<\
Automatically attempt to load data. If the file tda2000.txt is not in a \
subdirectory of your home directory, simply change the next expression to the \
line:
<<\"directory\\\\tda2000.txt\"
where 'directory' is the directory where the file tda2000.txt is kept, and \
all symbols \\ are replaced by \\\\.\
\>", "Text"],

Cell[BoxData[{
    \(\(filenames = 
        FileNames["\<tda2000.txt\>", $HomeDirectory, 
          Infinity];\)\), "\[IndentingNewLine]", 
    \(\(If[
        Length[filenames] \[GreaterEqual] 
          1, \[IndentingNewLine]\(Get[
            filenames\[LeftDoubleBracket]1\[RightDoubleBracket]];\)];\)\)}], \
"Input"],

Cell[BoxData[
    \(\(TraceDeriv[1] := TraceDeriv[0];\)\)], "Input"],

Cell[BoxData[
    \(\(\(\((\(TraceDeriv[#1\[LeftDoubleBracket]1\[RightDoubleBracket]] = 
                Abs[#1\[LeftDoubleBracket]2\[RightDoubleBracket]];\))\) &\) /@ 
        tracederivatives;\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Calculations", "Section"],

Cell[CellGroupData[{

Cell["Code", "Subsection"],

Cell[CellGroupData[{

Cell["Packages", "Subsubsection"],

Cell["<<Statistics`LinearRegression`", "Input",
  CellTags->"S6.1.1"],

Cell["<< Graphics`Graphics`", "Input",
  CellTags->"S5.32.1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Trace derivative ratio behaviour", "Subsubsection"],

Cell["\<\
This function builds a table of samples which are pairs (r1,r2,a) of \
sequential partial approximants to uniformly randomly chosen numbers in [0,1] \
with the limitation that the denominators must be smaller than maxdenom, this \
pair has the corresponding partial quotient a\
\>", "Text"],

Cell[BoxData[
    \(\(BuildGlobalSampleTable[numtrials_, maxdenom_] := 
        Module[{cft, approximants, semisamlist}, \[IndentingNewLine]cft = 
            ContinuedFraction[
              Table[Random[], {numtrials}]]; \[IndentingNewLine]approximants \
= \(Select[#1, Function[x, 
                    Denominator[x] < 
                      maxdenom]] &\) /@ \((\(\((FromContinuedFraction /@ 
                        Table[Take[#1, i], {i, 1, Length[#1]}])\) &\) /@ 
                  cft)\); \[IndentingNewLine]semisamlist = 
            Table[{Take[cft\[LeftDoubleBracket]i\[RightDoubleBracket], 
                  Length[approximants\[LeftDoubleBracket]
                      i\[RightDoubleBracket]]], 
                approximants\[LeftDoubleBracket]i\[RightDoubleBracket]}, {i, 
                1, Length[cft]}]; \[IndentingNewLine]Union[
            Flatten[\(Table[{#1\[LeftDoubleBracket]2, 
                        i - 1\[RightDoubleBracket], #1\[LeftDoubleBracket]2, 
                        i\[RightDoubleBracket], #1\[LeftDoubleBracket]1, 
                        i\[RightDoubleBracket]}, {i, 2, 
                      Length[#1\[LeftDoubleBracket]1\[RightDoubleBracket]]}] \
&\) /@ semisamlist, 1]]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(\[CapitalDelta]T[{r1_, r2_, a_}] := 
        TraceDeriv[r2]/TraceDeriv[r1];\)\)], "Input"],

Cell["This long computational step builds the sample table", "Text"],

Cell[BoxData[
    \(NumTrials = 30000; MaxDenom = 2000;\)], "Input"],

Cell[BoxData[
    \(\(GlobalSampleTable = 
        BuildGlobalSampleTable[NumTrials, MaxDenom];\)\)], "Input"],

Cell["\<\
This step selects subsets of the sample table satisfying various conditions \
on the partial quotients\
\>", "Text"],

Cell[BoxData[
    \(\(\(\((\(SampleTable[#1] = 
                Select[GlobalSampleTable, 
                  Function[x, 
                    x\[LeftDoubleBracket]3\[RightDoubleBracket] \[Equal] \
#1]];\))\) &\) /@ Range[20];\)\)], "Input"],

Cell["\<\
Generate the summary stats by computing \[CapitalDelta]T applied to the \
sample tables\
\>", "Text"],

Cell[BoxData[
    \(\(For[n = 1, 
        n \[LessEqual] 
          20, \(n++\), \[IndentingNewLine]stE = \(\[CapitalDelta]T[#1] &\) /@ 
            SampleTable[n]; \[IndentingNewLine]SummaryStats[n] = {n, 
            Min[stE], Max[stE], 
            Length[stE]};\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(RestrictedSampleSet[n_, qmin_, qmax_] := 
        Select[SampleTable[n], 
          Denominator[#1\[LeftDoubleBracket]2\[RightDoubleBracket]] > qmin && 
              Denominator[#1\[LeftDoubleBracket]2\[RightDoubleBracket]] < 
                qmax &];\)\)], "Input"],

Cell["\<\
For the purposes of working out how much the summary stats depend on small \
denominator rationals, compute \[CapitalDelta]T for rationals whose \
denominators q satisfies 0<q<200; 200<q<700; 700<q<2000. The idea being if \
the stats are about the same, that lends some support to their being \
universal. At least, that's about as much support as we can hope for with the \
limitation on the denominators.\
\>", "Text"],

Cell[BoxData[
    \(\(For[n = 1, 
        n \[LessEqual] 
          20, \(n++\), \[IndentingNewLine]stE = \(\[CapitalDelta]T[#1] &\) /@ 
            RestrictedSampleSet[n, 200, 700]; \[IndentingNewLine]SummaryStats[
            n, 200, 700] = {n, Min[stE], Max[stE], 
            Length[stE]}; \[IndentingNewLine]stE = \(\[CapitalDelta]T[#1] &\) \
/@ RestrictedSampleSet[n, 0, 200]; \[IndentingNewLine]SummaryStats[n, 0, 
            200] = {n, Min[stE], Max[stE], 
            Length[stE]}; \[IndentingNewLine]stE = \(\[CapitalDelta]T[#1] &\) \
/@ RestrictedSampleSet[n, 700, 2000]; \[IndentingNewLine]SummaryStats[n, 700, 
            2000] = {n, Min[stE], Max[stE], 
            Length[stE]};\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Power law bounds", "Subsubsection"],

Cell["\<\
This function gives the relative frequency of the digit m in cfes chosen \
randomly according to Gauss' probability measure.\
\>", "Text"],

Cell[BoxData[
    \(\(RelativeFrequency[m_] := 
        Log[\((m + 1)\)^2/\((m \((m + 2)\))\)]/Log[2];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exponent histograms", "Subsubsection"],

Cell["Compute log T_n / log q_n for various restricted sample sets", "Text"],

Cell[BoxData[
    \(\(exponents[1, 2000] = 
        Function[z, 
            Log[Abs[z\[LeftDoubleBracket]2\[RightDoubleBracket]]]/
              Log[Denominator[z\[LeftDoubleBracket]1\[RightDoubleBracket]]]] /@ 
          Select[tracederivatives, 
            Denominator[#1\[LeftDoubleBracket]1\[RightDoubleBracket]] < 2000 && 
                Denominator[#1\[LeftDoubleBracket]1\[RightDoubleBracket]] > 
                  1 &];\)\)], "Input"],

Cell[BoxData[
    \(\(exponents[500, 2000] = 
        Function[z, 
            Log[Abs[z\[LeftDoubleBracket]2\[RightDoubleBracket]]]/
              Log[Denominator[z\[LeftDoubleBracket]1\[RightDoubleBracket]]]] /@ 
          Select[tracederivatives, 
            Denominator[#1\[LeftDoubleBracket]1\[RightDoubleBracket]] < 2000 && 
                Denominator[#1\[LeftDoubleBracket]1\[RightDoubleBracket]] > 
                  500 &];\)\)], "Input"],

Cell[BoxData[
    \(\(exponents[1000, 2000] = 
        Function[z, 
            Log[Abs[z\[LeftDoubleBracket]2\[RightDoubleBracket]]]/
              Log[Denominator[z\[LeftDoubleBracket]1\[RightDoubleBracket]]]] /@ 
          Select[tracederivatives, 
            Denominator[#1\[LeftDoubleBracket]1\[RightDoubleBracket]] < 2000 && 
                Denominator[#1\[LeftDoubleBracket]1\[RightDoubleBracket]] > 
                  1000 &];\)\)], "Input"],

Cell["\<\
This is just a shorthand for drawing histograms of these data with bars of \
width w\
\>", "Text"],

Cell[BoxData[
    \(\(AutoHist[list_, w_] := 
        Histogram[list, 
          HistogramCategories \[Rule] 
            Table[x, {x, Min[list], Max[list] + w, w}]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear regressions", "Subsubsection"],

Cell[BoxData[
    \(\(BuildGlobalLRSampleTable[numtrials_, maxdenom_] := 
        Module[{cft}, \[IndentingNewLine]cft = 
            ContinuedFraction[
              Table[Random[], {numtrials}]]; \[IndentingNewLine]\(Select[#1, 
                Function[x, 
                  Denominator[x] < 
                    maxdenom]] &\) /@ \((\(\((FromContinuedFraction /@ 
                      Table[Take[#1, i], {i, 1, Length[#1]}])\) &\) /@ 
                cft)\)\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(GlobalLRSampleTable = 
        BuildGlobalLRSampleTable[10000, 2000];\)\)], "Input"],

Cell[BoxData[
    \(\(Function[
          x, \(LRSampleTable[x] = 
              Select[GlobalLRSampleTable, 
                Length[#1] \[GreaterEqual] x &];\)] /@ 
        Range[14];\)\)], "Input"],

Cell[BoxData[
    \(\(PowerLawStatsTable = \({#1\[LeftDoubleBracket]1, 1, 2, 
                1\[RightDoubleBracket], #1\[LeftDoubleBracket]2\
\[RightDoubleBracket], #1\[LeftDoubleBracket]3\[RightDoubleBracket], #1\
\[LeftDoubleBracket]4\[RightDoubleBracket]} &\) /@ \(({ParameterTable, 
                RSquared, EstimatedVariance, SamplePoints} /. 
              Function[z, 
                  Append[Regress[z, {1, x}, x], 
                    SamplePoints \[Rule] Length[z]]] /@ \((Map[
                      Function[x, {Log[Denominator[x]], Log[TraceDeriv[x]]}], 
                      LRSampleTable[6], {2}] // N)\))\);\)\)], "Input"],

Cell[BoxData[
    \(\(LRSampleTableArray = 
        Table[\(LRSampleTable[8]\)\[LeftDoubleBracket]
            Random[Integer, 
              Length[LRSampleTable[8]]]\[RightDoubleBracket], {i, 1, 3}, {j, 
            1, 3}];\)\)], "Input"],

Cell[BoxData[
    \(\(LogTLogqGraph[sam_] := 
        Module[{l, r, g, p, xmax, ymax, a, 
            b}, \[IndentingNewLine]l = \({Log[Denominator[#1]], 
                  Log[TraceDeriv[#1]]} &\) /@ sam; \[IndentingNewLine]r = 
            ParameterTable /. Regress[l, {1, x}, x]; \[IndentingNewLine]a = 
            r\[LeftDoubleBracket]1, 1, 
              1\[RightDoubleBracket]; \[IndentingNewLine]b = 
            r\[LeftDoubleBracket]1, 2, 
              1\[RightDoubleBracket]; \[IndentingNewLine]xmax = 
            Max[\(#1\[LeftDoubleBracket]1\[RightDoubleBracket] &\) /@ 
                l]; \[IndentingNewLine]ymax = 
            Max[\(#1\[LeftDoubleBracket]2\[RightDoubleBracket] &\) /@ 
                l]; \[IndentingNewLine]g\  = 
            ListPlot[l, DisplayFunction \[Rule] Identity, 
              PlotStyle \[Rule] {PointSize[0.02]}]; \[IndentingNewLine]p = 
            Graphics[{RGBColor[0.7, 0.7, 0.7], 
                Polygon[{{0, 0}, {xmax, PowerLawUpperBound*xmax}, {xmax, 
                      PowerLawLowerBound*xmax}}], RGBColor[0, 0, 0], 
                Line[{{0, a}, {2*xmax, 
                      2*xmax*b + a}}]}]; \[IndentingNewLine]Show[{p, g}, 
            DisplayFunction \[Rule] Identity, Axes \[Rule] True, 
            PlotRange \[Rule] {{0, xmax}, {0, 
                  ymax}}]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(LogToverLogqGraph[sam_, col_] := 
        Module[{l}, \[IndentingNewLine]l = \({Log[Denominator[#1]], 
                  Log[TraceDeriv[#1]]/Log[Denominator[#1]]} &\) /@ 
              Select[sam, 
                Denominator[#1] \[GreaterEqual] 
                    2 &]; \[IndentingNewLine]ListPlot[l, 
            DisplayFunction \[Rule] Identity, PlotJoined \[Rule] True, 
            PlotStyle \[Rule] {RGBColor[
                  Sequence @@ col]}]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Results", "Subsection"],

Cell[CellGroupData[{

Cell["Trace derivative ratio behaviour", "Subsubsection"],

Cell["\<\
Summary stats for \[CapitalDelta]T applied to the full sample table\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[SummaryStats[n], {n, 1, 20}] // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "1.`", "3.464101599439017`", "30718"},
          {"2", "3.464101599439017`", "6.97359002001688`", "12174"},
          {"3", "6.973590080603641`", "11.874987494135935`", "6666"},
          {"4", "11.874987476195805`", "18.938378726847418`", "4084"},
          {"5", "18.938378796730014`", "28.95227514194826`", "2872"},
          {"6", "28.952275254167596`", "42.607257924127005`", "2098"},
          {"7", "42.60725808029334`", "60.53563636864117`", "1605"},
          {"8", "60.53563640345404`", "83.34871362106392`", "1239"},
          {"9", "83.3487137310651`", "111.65198715118363`", "1025"},
          {"10", "111.65198731992643`", "146.04998273957514`", "778"},
          {"11", "146.04998329554272`", "187.14757556729822`", "713"},
          {"12", "187.14757599268887`", "235.55022695137595`", "549"},
          {"13", "235.55022777169975`", "291.86394093620487`", "508"},
          {"14", "291.8639420894581`", "356.6951501633444`", "459"},
          {"15", "356.6951518797869`", "430.6506225674718`", "382"},
          {"16", "430.65062503284366`", "514.337375940636`", "294"},
          {"17", "514.3373777697951`", "608.362612744186`", "320"},
          {"18", "608.3626150715853`", "713.3336921272004`", "288"},
          {"19", "713.3336937564928`", "829.858070919886`", "232"},
          {"20", "829.8580730573042`", "958.5432987999022`", "225"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Summary stats for \[CapitalDelta]T applied to the 0<q<200 sample table\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[SummaryStats[n, 0, 200], {n, 1, 20}] // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "1.`", "3.464101599439017`", "7777"},
          {"2", "3.464101599439017`", "6.97359002001688`", "2831"},
          {"3", "6.973590080603641`", "11.874987494135935`", "1466"},
          {"4", "11.874987476195805`", "18.938378726847418`", "884"},
          {"5", "18.938378796730014`", "28.95227514194826`", "625"},
          {"6", "28.952275254167596`", "42.607257924127005`", "438"},
          {"7", "42.60725808029334`", "60.53563636864117`", "337"},
          {"8", "60.53563640345404`", "83.34871362106392`", "257"},
          {"9", "83.3487137310651`", "111.65198715118363`", "203"},
          {"10", "111.65198731992643`", "146.04998273957514`", "163"},
          {"11", "146.04998329554272`", "187.14757556729822`", "147"},
          {"12", "187.14757599268887`", "235.55022695137595`", "113"},
          {"13", "235.55022777169975`", "291.86394093620487`", "93"},
          {"14", "291.8639420894581`", "356.6951501633444`", "91"},
          {"15", "356.6951518797869`", "430.6506225674718`", "76"},
          {"16", "430.65062503284366`", "514.337375940636`", "68"},
          {"17", "514.3373777697951`", "608.362612744186`", "63"},
          {"18", "608.3626150715853`", "713.3336921272004`", "55"},
          {"19", "713.3336937564928`", "829.858070919886`", "49"},
          {"20", "829.8580730573042`", "958.5432987999022`", "39"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Summary stats for \[CapitalDelta]T applied to the 200<q<700 sample table\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[SummaryStats[n, 200, 700], {n, 1, 20}] // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "1.0043731143565162`", "3.4489041478595586`", "12033"},
          {"2", "3.4792006307517234`", "6.947159286994191`", "4887"},
          {"3", "7.004431440478204`", "11.837874849636936`", "2709"},
          {"4", "11.912042602925167`", "18.8895688634459`", "1647"},
          {"5", "18.98892838750041`", "28.894492385932253`", "1160"},
          {"6", "29.006133152372485`", "42.53541802848045`", "847"},
          {"7", "42.66607806935604`", "60.44190088769043`", "640"},
          {"8", "60.596721385448554`", "83.2516461182337`", "524"},
          {"9", "83.41776752136316`", "111.53862324296874`", "434"},
          {"10", "111.71525720726466`", "145.91699552210102`", "311"},
          {"11", "146.1092687144719`", "186.987534732034`", "298"},
          {"12", "187.20284488123013`", "235.30865366444314`", "224"},
          {"13", "235.6043053505143`", "291.6700680699062`", "202"},
          {"14", "291.9170374159346`", "356.44498767868674`", "181"},
          {"15", "356.74500754719816`", "430.39181249656116`", "154"},
          {"16", "430.7041529498013`", "514.0246581061222`", "114"},
          {"17", "514.3881374119582`", "607.9097246100636`", "126"},
          {"18", "608.4117607912472`", "712.6917963915034`", "118"},
          {"19", "713.3790502573744`", "829.4395707341695`", "96"},
          {"20", "829.9012904087633`", "957.8425859116079`", "97"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
Summary stats for \[CapitalDelta]T applied to the 700<q<2000 sample table\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[SummaryStats[n, 700, 2000], {n, 1, 20}] // TableForm\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"1", "1.0015974412681758`", "3.458308121665077`", "10880"},
          {"2", "3.4695248769825047`", "6.963736150392903`", "4435"},
          {"3", "6.983604657860299`", "11.86069488978835`", "2482"},
          {"4", "11.888358881473005`", "18.920714538155035`", "1549"},
          {"5", "18.95696738646329`", "28.93161336273412`", "1085"},
          {"6", "28.978802049506463`", "42.5713152627905`", "809"},
          {"7", "42.63198900491366`", "60.50785630137689`", "627"},
          {"8", "60.56576399343668`", "83.304801539425`", "455"},
          {"9", "83.37770423670447`", "111.61399887333977`", "387"},
          {"10", "111.68580500291664`", "146.01044591588126`", "303"},
          {"11", "146.09432081950504`", "187.10519934974747`", "266"},
          {"12", "187.20497937952643`", "235.45138680645397`", "212"},
          {"13", "235.59915617952592`", "291.78566752222`", "213"},
          {"14", "291.9072466539342`", "356.62033308835436`", "187"},
          {"15", "356.7415859483739`", "430.56053842706467`", "151"},
          {"16", "430.6961661438046`", "514.2611241165184`", "112"},
          {"17", "514.3782300040458`", "608.2292296230473`", "131"},
          {"18", "608.4026895874218`", "713.2026902661521`", "114"},
          {"19", "713.3721872336449`", "829.6586027134097`", "87"},
          {"20", "829.8997814757146`", "957.7917000240083`", "89"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Power law bounds", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PowerLawLowerBound = 
      Sum[RelativeFrequency[m] Log[TraceDeriv[1/\((m)\)]], {m, 1, 
              2000}]/\((Pi^2/\((12\ Log[2])\))\) // N\)], "Input"],

Cell[BoxData[
    \(1.6984680469463695`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PowerLawUpperBound = 
      Sum[RelativeFrequency[m] Log[TraceDeriv[1/\((m + 1)\)]], {m, 1, 
              1999}]/\((Pi^2/\((12\ Log[2])\))\) // N\)], "Input"],

Cell[BoxData[
    \(2.3540744657549175`\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exponent histograms", "Subsubsection"],

Cell[BoxData[
    \(\(AutoHist[exponents[1, 2000], 0.01];\)\)], "Input"],

Cell[BoxData[
    \(\(AutoHist[exponents[500, 2000], 0.01];\)\)], "Input"],

Cell[BoxData[
    \(\(AutoHist[exponents[1000, 2000], 0.01];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear regressions", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[PowerLawStatsTable]\)], "Input"],

Cell[BoxData[
    \(8334\)], "Output"]
}, Open  ]],

Cell["Minimum and maximum exponents", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Min[\(#1\[LeftDoubleBracket]1\[RightDoubleBracket] &\) /@ 
        PowerLawStatsTable]\)], "Input"],

Cell[BoxData[
    \(1.6557459421798226`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Max[\(#1\[LeftDoubleBracket]1\[RightDoubleBracket] &\) /@ 
        PowerLawStatsTable]\)], "Input"],

Cell[BoxData[
    \(2.444607703285917`\)], "Output"]
}, Open  ]],

Cell["Minimum and mean r^2 coefficient", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Min[\(#1\[LeftDoubleBracket]2\[RightDoubleBracket] &\) /@ 
        PowerLawStatsTable]\)], "Input"],

Cell[BoxData[
    \(0.9859952860042728`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus @@ \((\(#1\[LeftDoubleBracket]2\[RightDoubleBracket] &\) /@ 
            PowerLawStatsTable)\)/Length[PowerLawStatsTable]\)], "Input"],

Cell[BoxData[
    \(0.9983506631410105`\)], "Output"]
}, Open  ]],

Cell["Maximum and mean estimated variance", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Max[\(#1\[LeftDoubleBracket]3\[RightDoubleBracket] &\) /@ 
        PowerLawStatsTable]\)], "Input"],

Cell[BoxData[
    \(0.4721212181762402`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus @@ \((\(#1\[LeftDoubleBracket]3\[RightDoubleBracket] &\) /@ 
            PowerLawStatsTable)\)/Length[PowerLawStatsTable]\)], "Input"],

Cell[BoxData[
    \(0.04508496080532326`\)], "Output"]
}, Open  ]],

Cell["\<\
Histogram of exponents, compare to log T_n / log q_n histogram\
\>", "Text"],

Cell[BoxData[
    \(\(AutoHist[\((\(#1\[LeftDoubleBracket]1\[RightDoubleBracket] &\) /@ 
            PowerLawStatsTable)\), 0.01];\)\)], "Input"],

Cell["Nine sample graphs", "Text"],

Cell[BoxData[
    \(\(Show[
        GraphicsArray[
          Map[LogTLogqGraph, LRSampleTableArray, {2}]]];\)\)], "Input"],

Cell[BoxData[
    \(\(Show[
        Table[LogToverLogqGraph[
            GlobalLRSampleTable[\([Random[Integer, 8000]]\)], {Random[], 
              Random[], Random[]}], {50}], 
        DisplayFunction \[Rule] $DisplayFunction, AspectRatio \[Rule] 1/3, 
        PlotRange \[Rule] {{Log[2], Log[2000]}, {1.5, 2.6}}];\)\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Summary of Results", "Section"],

Cell["\<\
This table gives the ratio of the nth to the (n-1)th trace derivative when \
the nth partial quotient is N, and compares it to the size of the 1/N and \
1/(N+1) trace derivatives.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[
      Table[\(Join[
              Take[#1, 
                3], {TraceDeriv[
                  1/#1\[LeftDoubleBracket]1\[RightDoubleBracket]], 
                TraceDeriv[
                  1/\((#1\[LeftDoubleBracket]1\[RightDoubleBracket] + 1)\)]}, 
              Take[#1, \(-1\)]] &\)[SummaryStats[n]], {n, 1, 20}], 
      TableHeadings \[Rule] {None, {"\<N\>", \*"\"\<min \!\(T\_n\)/\!\(T\_\(n \
- 1\)\)\>\"", \*"\"\<max \!\(T\_n\)/\!\(T\_\(n - 1\)\)\>\"", \
\*"\"\<\!\(T\_\(1/N\)\)\>\"", \*"\"\<\!\(T\_\(1/\((N + 1)\)\)\)\>\"", \
"\<Samples\>"}}]\)], "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"N\"\>", "\<\"min \\!\\(T\\_n\\)/\\!\\(T\\_\\(n - \
1\\)\\)\"\>", "\<\"max \\!\\(T\\_n\\)/\\!\\(T\\_\\(n - 1\\)\\)\"\>", "\<\"\\!\
\\(T\\_\\(1/N\\)\\)\"\>", "\<\"\\!\\(T\\_\\(1/\\((N + 1)\\)\\)\\)\"\>", \
"\<\"Samples\"\>"},
          {"1", "1.`", "3.464101599439017`", "0.999999996961265`", 
            "3.46410158891253`", "30718"},
          {"2", "3.464101599439017`", "6.97359002001688`", 
            "3.46410158891253`", "6.973590059412748`", "12174"},
          {"3", "6.973590080603641`", "11.874987494135935`", 
            "6.973590059412748`", "11.874987440110864`", "6666"},
          {"4", "11.874987476195805`", "18.938378726847418`", 
            "11.874987440110864`", "18.9383787391813`", "4084"},
          {"5", "18.938378796730014`", "28.95227514194826`", 
            "18.9383787391813`", "28.952275166189303`", "2872"},
          {"6", "28.952275254167596`", "42.607257924127005`", 
            "28.952275166189303`", "42.60725795082117`", "2098"},
          {"7", "42.60725808029334`", "60.53563636864117`", 
            "42.60725795082117`", "60.53563621950228`", "1605"},
          {"8", "60.53563640345404`", "83.34871362106392`", 
            "60.53563621950228`", "83.34871347779045`", "1239"},
          {"9", "83.3487137310651`", "111.65198715118363`", 
            "83.34871347779045`", "111.65198698064563`", "1025"},
          {"10", "111.65198731992643`", "146.04998273957514`", 
            "111.65198698064563`", "146.0499828517355`", "778"},
          {"11", "146.04998329554272`", "187.14757556729822`", 
            "146.0499828517355`", "187.14757542399698`", "713"},
          {"12", "187.14757599268887`", "235.55022695137595`", 
            "187.14757542399698`", "235.55022705592503`", "549"},
          {"13", "235.55022777169975`", "291.86394093620487`", 
            "235.55022705592503`", "291.8639412025609`", "508"},
          {"14", "291.8639420894581`", "356.6951501633444`", 
            "291.8639412025609`", "356.69515079588484`", "459"},
          {"15", "356.6951518797869`", "430.6506225674718`", 
            "356.69515079588484`", "430.6506237242105`", "382"},
          {"16", "430.65062503284366`", "514.337375940636`", 
            "430.6506237242105`", "514.3373762068601`", "294"},
          {"17", "514.3373777697951`", "608.362612744186`", 
            "514.3373762068601`", "608.3626132229325`", "320"},
          {"18", "608.3626150715853`", "713.3336921272004`", 
            "608.3626132229325`", "713.3336915888608`", "288"},
          {"19", "713.3336937564928`", "829.858070919886`", 
            "713.3336915888608`", "829.8580705355854`", "232"},
          {"20", "829.8580730573042`", "958.5432987999022`", 
            "829.8580705355854`", "958.5432987602437`", "225"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableHeadings -> {None, {"N", 
        "min \!\(T\_n\)/\!\(T\_\(n - 1\)\)", 
        "max \!\(T\_n\)/\!\(T\_\(n - 1\)\)", "\!\(T\_\(1/N\)\)", 
        "\!\(T\_\(1/\((N + 1)\)\)\)", "Samples"}}]&)]], "Output"]
}, Open  ]],

Cell["\<\
The next two numbers give the minimum and maximum values of lim inf log T_n / \
log q_n for almost all \[Omega] assuming that the conjecture based on the \
table above is correct\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[
          RelativeFrequency[m] Log[TraceDeriv[1/\((m)\)]], {m, 1, 
            2000}]/\((Pi^2/\((12\ Log[2])\))\) // N\)], "Input"],

Cell[BoxData[
    \(1.6984680469463695`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[
          RelativeFrequency[m] Log[TraceDeriv[1/\((m + 1)\)]], {m, 1, 
            1999}]/\((Pi^2/\((12\ Log[2])\))\) // N\)], "Input"],

Cell[BoxData[
    \(2.3540744657549175`\)], "Output"]
}, Open  ]],

Cell["Histogram of values of log T_n / log q_n", "Text"],

Cell[BoxData[
    \(\(AutoHist[exponents[1, 2000], 0.01];\)\)], "Input"],

Cell["\<\
Minimum and maximum exponents from linear regression analysis\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Min[\(#1\[LeftDoubleBracket]1\[RightDoubleBracket] &\) /@ 
        PowerLawStatsTable]\)], "Input"],

Cell[BoxData[
    \(1.6557459421798226`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Max[\(#1\[LeftDoubleBracket]1\[RightDoubleBracket] &\) /@ 
        PowerLawStatsTable]\)], "Input"],

Cell[BoxData[
    \(2.444607703285917`\)], "Output"]
}, Open  ]],

Cell["Minimum and mean r^2 coefficient", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Min[\(#1\[LeftDoubleBracket]2\[RightDoubleBracket] &\) /@ 
        PowerLawStatsTable]\)], "Input"],

Cell[BoxData[
    \(0.9859952860042728`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus @@ \((\(#1\[LeftDoubleBracket]2\[RightDoubleBracket] &\) /@ 
            PowerLawStatsTable)\)/Length[PowerLawStatsTable]\)], "Input"],

Cell[BoxData[
    \(0.9983506631410105`\)], "Output"]
}, Open  ]],

Cell["Maximum and mean estimated variance", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Max[\(#1\[LeftDoubleBracket]3\[RightDoubleBracket] &\) /@ 
        PowerLawStatsTable]\)], "Input"],

Cell[BoxData[
    \(0.4721212181762402`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Plus @@ \((\(#1\[LeftDoubleBracket]3\[RightDoubleBracket] &\) /@ 
            PowerLawStatsTable)\)/Length[PowerLawStatsTable]\)], "Input"],

Cell[BoxData[
    \(0.04508496080532326`\)], "Output"]
}, Open  ]],

Cell["Nine sample graphs", "Text"],

Cell[BoxData[
    \(\(Show[
        GraphicsArray[
          Map[LogTLogqGraph, LRSampleTableArray, {2}]]];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1440}, {0, 827}},
WindowSize->{928, 731},
WindowMargins->{{1, Automatic}, {15, Automatic}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S6.1.1"->{
    Cell[2972, 97, 69, 1, 30, "Input",
      CellTags->"S6.1.1"]},
  "S5.32.1"->{
    Cell[3044, 100, 61, 1, 30, "Input",
      CellTags->"S5.32.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S6.1.1", 31230, 871},
  {"S5.32.1", 31312, 874}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 59, 0, 105, "Title"],

Cell[CellGroupData[{
Cell[1823, 55, 31, 0, 53, "Section"],
Cell[1857, 57, 328, 7, 71, "Text"],
Cell[2188, 66, 321, 8, 70, "Input"],
Cell[2512, 76, 68, 1, 30, "Input"],
Cell[2583, 79, 209, 3, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2829, 87, 31, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[2885, 91, 26, 0, 47, "Subsection"],

Cell[CellGroupData[{
Cell[2936, 95, 33, 0, 43, "Subsubsection"],
Cell[2972, 97, 69, 1, 30, "Input",
  CellTags->"S6.1.1"],
Cell[3044, 100, 61, 1, 30, "Input",
  CellTags->"S5.32.1"]
}, Closed]],

Cell[CellGroupData[{
Cell[3142, 106, 57, 0, 29, "Subsubsection"],
Cell[3202, 108, 300, 5, 52, "Text"],
Cell[3505, 115, 1250, 20, 210, "Input"],
Cell[4758, 137, 112, 2, 30, "Input"],
Cell[4873, 141, 68, 0, 33, "Text"],
Cell[4944, 143, 68, 1, 30, "Input"],
Cell[5015, 146, 110, 2, 30, "Input"],
Cell[5128, 150, 126, 3, 33, "Text"],
Cell[5257, 155, 240, 5, 30, "Input"],
Cell[5500, 162, 111, 3, 33, "Text"],
Cell[5614, 167, 301, 6, 90, "Input"],
Cell[5918, 175, 289, 5, 50, "Input"],
Cell[6210, 182, 430, 7, 71, "Text"],
Cell[6643, 191, 731, 12, 170, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7411, 208, 41, 0, 29, "Subsubsection"],
Cell[7455, 210, 148, 3, 33, "Text"],
Cell[7606, 215, 117, 2, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7760, 222, 44, 0, 29, "Subsubsection"],
Cell[7807, 224, 76, 0, 33, "Text"],
Cell[7886, 226, 445, 8, 50, "Input"],
Cell[8334, 236, 449, 8, 50, "Input"],
Cell[8786, 246, 451, 8, 50, "Input"],
Cell[9240, 256, 108, 3, 33, "Text"],
Cell[9351, 261, 181, 4, 50, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[9569, 270, 43, 0, 29, "Subsubsection"],
Cell[9615, 272, 498, 9, 110, "Input"],
Cell[10116, 283, 106, 2, 30, "Input"],
Cell[10225, 287, 199, 5, 30, "Input"],
Cell[10427, 294, 641, 10, 90, "Input"],
Cell[11071, 306, 240, 5, 30, "Input"],
Cell[11314, 313, 1364, 23, 290, "Input"],
Cell[12681, 338, 512, 9, 90, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[13242, 353, 29, 0, 31, "Subsection"],

Cell[CellGroupData[{
Cell[13296, 357, 57, 0, 43, "Subsubsection"],
Cell[13356, 359, 91, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[13472, 365, 80, 1, 30, "Input"],
Cell[13555, 368, 1579, 27, 329, "Output"]
}, Open  ]],
Cell[15149, 398, 94, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[15268, 404, 88, 1, 30, "Input"],
Cell[15359, 407, 1563, 27, 329, "Output"]
}, Open  ]],
Cell[16937, 437, 96, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[17058, 443, 90, 1, 30, "Input"],
Cell[17151, 446, 1589, 27, 329, "Output"]
}, Open  ]],
Cell[18755, 476, 97, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[18877, 482, 91, 1, 30, "Input"],
Cell[18971, 485, 1586, 27, 329, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[20606, 518, 41, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[20672, 522, 175, 3, 30, "Input"],
Cell[20850, 527, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20940, 533, 179, 3, 30, "Input"],
Cell[21122, 538, 53, 1, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[21224, 545, 44, 0, 29, "Subsubsection"],
Cell[21271, 547, 72, 1, 30, "Input"],
Cell[21346, 550, 74, 1, 30, "Input"],
Cell[21423, 553, 75, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[21535, 559, 43, 0, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[21603, 563, 59, 1, 30, "Input"],
Cell[21665, 566, 38, 1, 29, "Output"]
}, Open  ]],
Cell[21718, 570, 45, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[21788, 574, 119, 2, 30, "Input"],
Cell[21910, 578, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22000, 584, 119, 2, 30, "Input"],
Cell[22122, 588, 52, 1, 29, "Output"]
}, Open  ]],
Cell[22189, 592, 48, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[22262, 596, 119, 2, 30, "Input"],
Cell[22384, 600, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22474, 606, 159, 2, 30, "Input"],
Cell[22636, 610, 53, 1, 29, "Output"]
}, Open  ]],
Cell[22704, 614, 51, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[22780, 618, 119, 2, 30, "Input"],
Cell[22902, 622, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22992, 628, 159, 2, 30, "Input"],
Cell[23154, 632, 54, 1, 29, "Output"]
}, Open  ]],
Cell[23223, 636, 86, 2, 33, "Text"],
Cell[23312, 640, 145, 2, 30, "Input"],
Cell[23460, 644, 34, 0, 33, "Text"],
Cell[23497, 646, 122, 3, 30, "Input"],
Cell[23622, 651, 331, 6, 50, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[24014, 664, 37, 0, 33, "Section"],
Cell[24054, 666, 203, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[24282, 674, 595, 12, 50, "Input"],
Cell[24880, 688, 3161, 54, 347, "Output"]
}, Open  ]],
Cell[28056, 745, 202, 4, 33, "Text"],

Cell[CellGroupData[{
Cell[28283, 753, 156, 3, 30, "Input"],
Cell[28442, 758, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28532, 764, 160, 3, 30, "Input"],
Cell[28695, 769, 53, 1, 29, "Output"]
}, Open  ]],
Cell[28763, 773, 56, 0, 33, "Text"],
Cell[28822, 775, 72, 1, 30, "Input"],
Cell[28897, 778, 85, 2, 33, "Text"],

Cell[CellGroupData[{
Cell[29007, 784, 119, 2, 30, "Input"],
Cell[29129, 788, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29219, 794, 119, 2, 30, "Input"],
Cell[29341, 798, 52, 1, 29, "Output"]
}, Open  ]],
Cell[29408, 802, 48, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[29481, 806, 119, 2, 30, "Input"],
Cell[29603, 810, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29693, 816, 159, 2, 30, "Input"],
Cell[29855, 820, 53, 1, 29, "Output"]
}, Open  ]],
Cell[29923, 824, 51, 0, 33, "Text"],

Cell[CellGroupData[{
Cell[29999, 828, 119, 2, 30, "Input"],
Cell[30121, 832, 53, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30211, 838, 159, 2, 30, "Input"],
Cell[30373, 842, 54, 1, 29, "Output"]
}, Open  ]],
Cell[30442, 846, 34, 0, 33, "Text"],
Cell[30479, 848, 122, 3, 30, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

